@@ -33,6 +33,7 @@
 #include <stdlib.h>
 #include <libdmapsharing/dmap.h>
 
+#include "grl-dpap-compat.h"
 #include "grl-common.h"
 #include "grl-dpap.h"
 #include "grl-dpap-db.h"
@@ -42,7 +43,7 @@
 /* --------- Logging  -------- */
 
 #define GRL_LOG_DOMAIN_DEFAULT dmap_log_domain
-GRL_LOG_DOMAIN_STATIC(dmap_log_domain);
+GRL_LOG_DOMAIN_STATIC (dmap_log_domain);
 
 /* --- Plugin information --- */
 
@@ -51,18 +52,18 @@ GRL_LOG_DOMAIN_STATIC(dmap_log_domain);
 
 /* --- Grilo DPAP Private --- */
 
-#define GRL_DPAP_SOURCE_GET_PRIVATE(object)           \
-  (G_TYPE_INSTANCE_GET_PRIVATE((object),              \
-                               GRL_DPAP_SOURCE_TYPE,  \
-                               GrlDpapSourcePrivate))
+#define GRL_DPAP_SOURCE_GET_PRIVATE(object)            \
+  (G_TYPE_INSTANCE_GET_PRIVATE ((object),              \
+                                 GRL_DPAP_SOURCE_TYPE, \
+                                 GrlDpapSourcePrivate))
 
 struct _GrlDpapSourcePrivate {
-  DMAPMdnsBrowserService *service;
+  DmapMdnsService *service;
 };
 
 /* --- Data types --- */
 
-static GrlDpapSource *grl_dpap_source_new (DMAPMdnsBrowserService *service);
+static GrlDpapSource *grl_dpap_source_new (DmapMdnsService *service);
 
 static void grl_dpap_source_finalize (GObject *object);
 
@@ -79,16 +80,16 @@ static void grl_dpap_source_search (GrlSource *source,
                                     GrlSourceSearchSpec *ss);
 
 
-static void grl_dpap_service_added_cb (DMAPMdnsBrowser *browser,
-                                       DMAPMdnsBrowserService *service,
+static void grl_dpap_service_added_cb (DmapMdnsBrowser *browser,
+                                       DmapMdnsService *service,
                                        GrlPlugin *plugin);
 
-static void grl_dpap_service_removed_cb (DMAPMdnsBrowser *browser,
+static void grl_dpap_service_removed_cb (DmapMdnsBrowser *browser,
                                          const gchar *service_name,
                                          GrlPlugin *plugin);
 
 /* ===================== Globals  ======================= */
-static DMAPMdnsBrowser *browser;
+static DmapMdnsBrowser *browser;
 /* Maps URIs to DBs */
 static GHashTable *connections;
 /* Map DPAP services to Grilo media sources */
@@ -111,24 +112,24 @@ grl_dpap_plugin_init (GrlRegistry *registry,
   bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
-  browser     = dmap_mdns_browser_new (DMAP_MDNS_BROWSER_SERVICE_TYPE_DPAP);
+  browser     = dmap_mdns_browser_new (DMAP_MDNS_SERVICE_TYPE_DPAP);
   connections = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
   sources     = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
 
   g_signal_connect (G_OBJECT (browser),
-                    "service-added",
+                   "service-added",
                     G_CALLBACK (grl_dpap_service_added_cb),
                     (gpointer) plugin);
 
   g_signal_connect (G_OBJECT (browser),
-                    "service-removed",
+                   "service-removed",
                     G_CALLBACK (grl_dpap_service_removed_cb),
                     (gpointer) plugin);
 
   if (!dmap_mdns_browser_start (browser, &error)) {
     GRL_DEBUG ("error starting browser. code: %d message: %s",
-               error->code,
-               error->message);
+                error->code,
+                error->message);
     g_error_free (error);
 
     g_hash_table_unref (connections);
@@ -143,12 +144,12 @@ grl_dpap_plugin_init (GrlRegistry *registry,
 GRL_PLUGIN_DEFINE (GRL_MAJOR,
                    GRL_MINOR,
                    DPAP_PLUGIN_ID,
-                   "DPAP",
-                   "A plugin for browsing DPAP servers",
-                   "W. Michael Petullo",
+                  "DPAP",
+                  "A plugin for browsing DPAP servers",
+                  "W. Michael Petullo",
                    VERSION,
-                   "LGPL",
-                   "http://www.flyn.org",
+                  "LGPL",
+                  "http://www.flyn.org",
                    grl_dpap_plugin_init,
                    NULL,
                    NULL);
@@ -158,8 +159,10 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
 G_DEFINE_TYPE_WITH_PRIVATE (GrlDpapSource, grl_dpap_source, GRL_TYPE_SOURCE)
 
 static GrlDpapSource *
-grl_dpap_source_new (DMAPMdnsBrowserService *service)
+grl_dpap_source_new (DmapMdnsService *service)
 {
+  gchar *name;
+  gchar *service_name;
   gchar *source_desc;
   gchar *source_id;
 
@@ -167,20 +170,24 @@ grl_dpap_source_new (DMAPMdnsBrowserService *service)
 
   GRL_DEBUG ("grl_dpap_source_new");
 
-  source_desc = g_strdup_printf (SOURCE_DESC_TEMPLATE, service->name);
-  source_id = g_strdup_printf (SOURCE_ID_TEMPLATE, service->name);
+  name = grl_dmap_service_get_name (service);
+  service_name = grl_dmap_service_get_service_name (service);
+  source_desc = g_strdup_printf (SOURCE_DESC_TEMPLATE, name);
+  source_id = g_strdup_printf (SOURCE_ID_TEMPLATE, name);
 
   source = g_object_new (GRL_DPAP_SOURCE_TYPE,
-                         "source-id",   source_id,
-                         "source-name", service->name,
-                         "source-desc", source_desc,
-                         "supported-media", GRL_SUPPORTED_MEDIA_IMAGE,
+                        "source-id",   source_id,
+                        "source-name", service_name,
+                        "source-desc", source_desc,
+                        "supported-media", GRL_SUPPORTED_MEDIA_IMAGE,
                          NULL);
 
   source->priv->service = service;
 
   g_free (source_desc);
   g_free (source_id);
+  g_free (service_name);
+  g_free (name);
 
   return source;
 }
@@ -214,14 +221,14 @@ grl_dpap_source_finalize (GObject *object)
 static void
 grl_dpap_do_browse (ResultCbAndArgsAndDb *cb_and_db)
 {
-  grl_dpap_db_browse(GRL_DPAP_DB(cb_and_db->db),
-                     cb_and_db->cb.container,
-                     cb_and_db->cb.source,
-                     cb_and_db->cb.op_id,
-                     cb_and_db->cb.skip,
-                     cb_and_db->cb.count,
-                     cb_and_db->cb.callback,
-                     cb_and_db->cb.user_data);
+  grl_dpap_db_browse (GRL_DPAP_DB (cb_and_db->db),
+                      cb_and_db->cb.container,
+                      cb_and_db->cb.source,
+                      cb_and_db->cb.op_id,
+                      cb_and_db->cb.skip,
+                      cb_and_db->cb.count,
+                      cb_and_db->cb.callback,
+                      cb_and_db->cb.user_data);
 
   g_free (cb_and_db);
 }
@@ -229,19 +236,19 @@ grl_dpap_do_browse (ResultCbAndArgsAndDb *cb_and_db)
 static void
 grl_dpap_do_search (ResultCbAndArgsAndDb *cb_and_db)
 {
-  grl_dpap_db_search(GRL_DPAP_DB(cb_and_db->db),
-                     cb_and_db->cb.source,
-                     cb_and_db->cb.op_id,
-                     (GHRFunc) cb_and_db->cb.predicate,
-                     cb_and_db->cb.predicate_data,
-                     cb_and_db->cb.callback,
-                     cb_and_db->cb.user_data);
+  grl_dpap_db_search (GRL_DPAP_DB (cb_and_db->db),
+                      cb_and_db->cb.source,
+                      cb_and_db->cb.op_id,
+                      (GHRFunc) cb_and_db->cb.predicate,
+                      cb_and_db->cb.predicate_data,
+                      cb_and_db->cb.callback,
+                      cb_and_db->cb.user_data);
 
   g_free (cb_and_db);
 }
 
 static void
-browse_connected_cb (DMAPConnection       *connection,
+browse_connected_cb (DmapConnection       *connection,
                      gboolean              result,
                      const char           *reason,
                      ResultCbAndArgsAndDb *cb_and_db)
@@ -266,7 +273,7 @@ browse_connected_cb (DMAPConnection       *connection,
 }
 
 static void
-search_connected_cb (DMAPConnection       *connection,
+search_connected_cb (DmapConnection       *connection,
                      gboolean              result,
                      const char           *reason,
                      ResultCbAndArgsAndDb *cb_and_db)
@@ -291,8 +298,8 @@ search_connected_cb (DMAPConnection       *connection,
 }
 
 static void
-grl_dpap_service_added_cb (DMAPMdnsBrowser *browser,
-                           DMAPMdnsBrowserService *service,
+grl_dpap_service_added_cb (DmapMdnsBrowser *browser,
+                           DmapMdnsService *service,
                            GrlPlugin *plugin)
 {
   GrlRegistry   *registry = grl_registry_get_default ();
@@ -306,13 +313,16 @@ grl_dpap_service_added_cb (DMAPMdnsBrowser *browser,
                                 GRL_SOURCE (source),
                                 NULL);
   if (source != NULL) {
-    g_hash_table_insert (sources, g_strdup (service->name), g_object_ref (source));
+    gchar *name;
+    name = grl_dmap_service_get_name (service);
+    g_hash_table_insert (sources, g_strdup (name), g_object_ref (source));
     g_object_remove_weak_pointer (G_OBJECT (source), (gpointer *) &source);
+    g_free (name);
   }
 }
 
 static void
-grl_dpap_service_removed_cb (DMAPMdnsBrowser *browser,
+grl_dpap_service_removed_cb (DmapMdnsBrowser *browser,
                              const gchar *service_name,
                              GrlPlugin *plugin)
 {
@@ -328,14 +338,14 @@ grl_dpap_service_removed_cb (DMAPMdnsBrowser *browser,
 }
 
 static void
-grl_dpap_connect (gchar *name, gchar *host, guint port, ResultCbAndArgsAndDb *cb_and_db, DMAPConnectionCallback callback)
+grl_dpap_connect (gchar *name, gchar *host, guint port, ResultCbAndArgsAndDb *cb_and_db, DmapConnectionFunc callback)
 {
-  DMAPRecordFactory *factory;
-  DMAPConnection *connection;
+  DmapRecordFactory *factory;
+  DmapConnection *connection;
 
   factory = DMAP_RECORD_FACTORY (grl_dpap_record_factory_new ());
-  connection = DMAP_CONNECTION (dpap_connection_new (name, host, port, DMAP_DB (cb_and_db->db), factory));
-  dmap_connection_connect (connection, (DMAPConnectionCallback) callback, cb_and_db);
+  connection = DMAP_CONNECTION (dmap_image_connection_new (name, host, port, DMAP_DB (cb_and_db->db), factory));
+  dmap_connection_start (connection, (DmapConnectionFunc) callback, cb_and_db);
 }
 
 static gboolean
@@ -396,15 +406,25 @@ grl_dpap_source_browse (GrlSource *source,
     browse_connected_cb (NULL, TRUE, NULL, cb_and_db);
   } else {
     /* Connect */
+    gchar *name, *host;
+    guint port;
+
     cb_and_db->db = DMAP_DB (grl_dpap_db_new ());
 
-    grl_dpap_connect (dmap_source->priv->service->name,
-                      dmap_source->priv->service->host,
-                      dmap_source->priv->service->port,
+    name = grl_dmap_service_get_name (dmap_source->priv->service);
+    host = grl_dmap_service_get_host (dmap_source->priv->service);
+    port = grl_dmap_service_get_port (dmap_source->priv->service);
+
+    grl_dpap_connect (name,
+                      host,
+                      port,
                       cb_and_db,
-                      (DMAPConnectionCallback) browse_connected_cb);
+                      (DmapConnectionFunc) browse_connected_cb);
 
     g_hash_table_insert (connections, g_strdup (url), cb_and_db->db);
+
+    g_free (name);
+    g_free (host);
   }
 
   g_free (url);
@@ -416,7 +436,7 @@ static void grl_dpap_source_search (GrlSource *source,
   GrlDpapSource *dmap_source = GRL_DPAP_SOURCE (source);
 
   ResultCbAndArgsAndDb *cb_and_db;
-  DMAPMdnsBrowserService *service = dmap_source->priv->service;
+  DmapMdnsService *service = dmap_source->priv->service;
   gchar *url = grl_dmap_build_url (service);
 
   cb_and_db = g_new (ResultCbAndArgsAndDb, 1);
@@ -434,9 +454,25 @@ static void grl_dpap_source_search (GrlSource *source,
     search_connected_cb (NULL, TRUE, NULL, cb_and_db);
   } else {
     /* Connect */
+    gchar *name, *host;
+    guint port;
+
     cb_and_db->db = DMAP_DB (grl_dpap_db_new ());
-    grl_dpap_connect (service->name, service->host, service->port, cb_and_db, (DMAPConnectionCallback) search_connected_cb);
+
+    name = grl_dmap_service_get_name (dmap_source->priv->service);
+    host = grl_dmap_service_get_host (dmap_source->priv->service);
+    port = grl_dmap_service_get_port (dmap_source->priv->service);
+
+    grl_dpap_connect (name, 
+                      host,
+                      port,
+                      cb_and_db,
+                      (DmapConnectionFunc) search_connected_cb);
+
     g_hash_table_insert (connections, g_strdup (url), cb_and_db->db);
+
+    g_free (name);
+    g_free (host);
   }
 
   g_free (url);
