@@ -23,7 +23,7 @@
 -- Test the API at:
 -- http://explorer.content.guardianapis.com/search?api-key=rppwmmu3mfqj6gkbs8kcjg23&show-fields=all&page-size=50&tag=type/video
 API_KEY                          = 'rppwmmu3mfqj6gkbs8kcjg23'
-GUARDIANVIDEOS_URL               = 'http://content.guardianapis.com/search?tag=type/video&page=%s&page-size=%s&show-fields=all&api-key=%s'
+GUARDIANVIDEOS_URL               = 'http://content.guardianapis.com/search?tag=type/video&page=%d&page-size=%d&show-fields=all&api-key=%s'
 
 ---------------------------
 -- Source initialization --
@@ -37,7 +37,7 @@ source = {
   supported_media = 'video',
   auto_split_threshold = 50,
   icon = 'resource:///org/gnome/grilo/plugins/guardianvideos/guardianvideos.svg',
-  tags = { 'news', 'net:internet' }
+  tags = { 'news', 'net:internet', 'net:plaintext' }
 }
 
 ------------------
@@ -64,7 +64,7 @@ function grl_source_browse(media_id)
     table.insert(urls, url)
   end
 
-  grl.fetch(urls, "guardianvideos_fetch_cb")
+  grl.fetch(urls, guardianvideos_fetch_cb)
 end
 
 ------------------------
@@ -105,9 +105,32 @@ function create_media(item)
 
   media.type = "video"
   media.id = item.id
-  media.url = item.webUrl
-  media.title = item.webTitle
-  media.thumbnail = item.fields.thumbnail
+  media.title = grl.unescape(item.webTitle)
+
+  main = item.fields.main
+  -- Some entries rarely don't have a 'main' field. So, we bail out.
+  if not main then
+    grl.warning ("No media URL metadata found for: " .. media.title)
+    return media
+  end
+
+  media.url = main:match('src="(.-%.mp4)"')
+  media.thumbnail = main:match('poster="(.-%.jpg)"')
+
+  if not media.url then
+    grl.warning ("No media streaming URL found for: " .. media.title)
+    grl.debug ("Data from: " .. media.title .. "\n" .. grl.lua.inspect(item));
+  end
+
+  if not media.thumbnail then
+    -- Try to see if we have a 'thumbnail' field. This field seems
+    -- to exist for some entries, which don't have a 'poster' field
+    if item.fields.thumbnail then
+      media.thumbnail = item.fields.thumbnail
+    else
+      grl.debug ("No media thumbnail URL found for: " .. media.title)
+    end
+  end
 
   return media
 end
